@@ -2,16 +2,16 @@
  *                   Materials Object Library                  *
  *Class cubic_elasticity_tensor : for cubic symmetry materials *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2006,2008,2012 COLLARD Christophe
- * copyright © 2006,2008,2012 Centre National de la Recherche Scientifique
+ * copyright © 2006,2008,2012,2018 COLLARD Christophe
+ * copyright © 2006,2008,2012,2018 Centre National de la Recherche Scientifique
  * copyright © 2006,2008 Arts et Métiers ParisTech
  * copyright © 2006 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2006,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2012,2018 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -93,15 +93,15 @@
     \f$ \displaystyle c_{44} = c_{55} = c_{66} = \mu \f$ \n
     \f$ \displaystyle c_{12} = c_{21} = c_{13} = c_{31} = c_{23} = c_{32} = \frac{\nu E}{(1+\nu)(1-2\nu)} \f$. \n
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2006, 2008, 2012 Christophe COLLARD \n
-            copyright \htmlonly &#169; 2006, 2008, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2006, 2008, 2012, 2018 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2006, 2008, 2012, 2018 Centre National de la Recherche Scientifique \endhtmlonly \n
 	    copyright \htmlonly &#169; 2006, 2008 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	    copyright \htmlonly &#169; 2006 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
             copyright \htmlonly &#169; 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-	    copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2006-2012
+	    copyright \htmlonly &#169; 2012, 2018 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2006-2019
     \bug none
     \warning none
 */
@@ -134,6 +134,10 @@
 #include <string.h>
 #endif
 
+#ifndef __algorithm
+#include <algorithm>
+#endif
+
 #ifndef __tensors4_hpp
 #include "MOL++/tensors4.hpp"
 #endif
@@ -178,6 +182,7 @@ template <class T> class cubic_elasticity_tensor : public cubic_tensor<T>
     T Poisson () const {return nu;}
 
     template <class Tf> friend ostream& operator << (ostream&, cubic_elasticity_tensor<Tf>&);
+    void read (const char *); // reads elastic constants values from a file
 };
 
 
@@ -364,6 +369,49 @@ template <class Tf> ostream& operator << (ostream& s, cubic_elasticity_tensor<Tf
 }
 
 
+/*!
+  \brief Build \f$ \displaystyle 4^{th} \f$ order isotropic elasticity tensor from file.
+
+  \param path path + filename to read data
+*/
+
+//-------------------------------------------------------------------------
+template <class T> void cubic_elasticity_tensor<T>::read (const char* path)
+//-------------------------------------------------------------------------
+{
+  string text;
+  string cst_text;
+  T cst_value;
+
+  ifstream file (path, ios::in);
+  assert (!file.fail());
+  file >> text;
+
+  assert (text=="cubic");
+  for (int i=1; i<=3; i++)
+    { file >> text;
+      file >> cst_text;
+      transform (cst_text.begin(), cst_text.end(), cst_text.begin(), (int (*)(int)) tolower);
+      if (cst_text == "name")
+	{ getline (file, cst_text);
+	  getline (file, cst_text);
+	  name (cst_text);
+	  i--;
+	}
+      else
+	{ cst_value = read_value<T> (file);
+	  if (cst_text == "young") Young (cst_value);
+	  else if (cst_text == "shear") Shear (cst_value);
+	  else if (cst_text == "poisson") Poisson (cst_value);
+	  else
+	    { cout << red << "error in file " << path << ": unknown constant name " << cst_text << endl << "Please give the following constants: Young, Shear, Poisson" << reset;
+	      exit(0);
+	    }
+	}
+    }
+}
+
+
 }
 
 
