@@ -2,17 +2,17 @@
  *                   Materials Object Library                  *
  *              Class isotropic_elasticity_tensor              *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2002,2003,2004,2005,2006,2008,2011,2012 COLLARD Christophe
- * copyright © 2002,2003,2004,2005,2006,2008,2011,2012 Centre National de la Recherche Scientifique
+ * copyright © 2002,2003,2004,2005,2006,2008,2011,2012,2018 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2008,2011,2012,2018 Centre National de la Recherche Scientifique
  * copyright © 2002,2003,2004,2005,2006,2008,2011 Arts et Métiers ParisTech
  * copyright © 2002,2003,2004,2005,2006 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2002,2003,2004,2005,2006,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2002,2003,2004,2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
- * copyright © 2011,2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2011,2012,2018 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -96,16 +96,16 @@
     \hline
     \end{tabular}} \f$
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008, 2011, 2012 Christophe COLLARD \n
-            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2011, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008, 2011, 2012, 2018 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2011, 2012, 2018 Centre National de la Recherche Scientifique \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
             copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de MM&#233;canique des MatM&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
-            copyright \htmlonly &#169; 2011, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2002-2012
+            copyright \htmlonly &#169; 2011, 2012, 2018 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2002-2019
     \bug none
     \warning none
 */
@@ -142,6 +142,14 @@
 #include <string.h>
 #endif
 
+#ifndef __algorithm
+#include <algorithm>
+#endif
+
+#ifndef __tools_hpp
+#include "tools.hpp"
+#endif
+
 #ifndef __tensors4_hpp
 #include "MOL++/tensors4.hpp"
 #endif
@@ -169,7 +177,7 @@ template <class T> class isotropic_elasticity_tensor : public isotropic_tensor<T
     T lame, shear, nu, E, K;
 
   public :
-    isotropic_elasticity_tensor (char* name= "");  // default constructor
+    isotropic_elasticity_tensor (string name= "");  // default constructor
     isotropic_elasticity_tensor (const tensor4<T>&); // cast conversion
     isotropic_elasticity_tensor (const isotropic_tensor<T>&); // cast convertion
     ~isotropic_elasticity_tensor () {}  // destructor
@@ -191,6 +199,7 @@ template <class T> class isotropic_elasticity_tensor : public isotropic_tensor<T
     T lambda (T);
     T mu     (T);
     template <class Tf> friend ostream& operator << (ostream&, const isotropic_elasticity_tensor<Tf>&);
+    void read (const char *); // reads elastic constants values from a file
 };
 
 
@@ -206,9 +215,9 @@ template <class T> class isotropic_elasticity_tensor : public isotropic_tensor<T
   \param name tensor name
 */
 
-//---------------------------------------------------------------------------------------------------------------------
-template <class T> isotropic_elasticity_tensor<T>::isotropic_elasticity_tensor (char* name) : isotropic_tensor<T>(name)
-//---------------------------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
+template <class T> isotropic_elasticity_tensor<T>::isotropic_elasticity_tensor (string name) : isotropic_tensor<T>(name)
+//----------------------------------------------------------------------------------------------------------------------
 {
   lame = shear = nu = E = K = 0;
   tensor_name = name;
@@ -536,6 +545,51 @@ template <class Tf> ostream& operator << (ostream& s, const isotropic_elasticity
 }
 
 
+/*!
+  \brief Build \f$ \displaystyle 4^{th} \f$ order isotropic elasticity tensor from file.
+
+  \param path path + filename to read data
+*/
+
+//-----------------------------------------------------------------------------
+template <class T> void isotropic_elasticity_tensor<T>::read (const char* path)
+//-----------------------------------------------------------------------------
+{
+  string text;
+  string cst_text;
+  T cst_value;
+
+  ifstream file (path, ios::in);
+  assert (!file.fail());
+  file >> text;
+
+  assert (text=="isotropic");
+  for (int i=1; i<=2; i++)
+    { file >> text;
+      file >> cst_text;
+      transform (cst_text.begin(), cst_text.end(), cst_text.begin(), (int (*)(int)) tolower);
+      if (cst_text == "name")
+	{ getline (file, cst_text);
+	  getline (file, cst_text);
+	  tensor_name = cst_text;
+	  i--;
+	}
+      else
+	{ cst_value = read_value<T> (file);
+	  if (cst_text == "lame") Lame (cst_value);
+	  else if (cst_text == "shear") Shear (cst_value);
+	  else if (cst_text == "young") Young (cst_value);
+	  else if (cst_text == "poisson") Poisson (cst_value);
+	  else if (cst_text == "bulk") Bulk (cst_value);
+	  else
+	    { cout << red << "error in file " << path << ": unknown constant name " << cst_text << endl << "Please choose 2 of the following constants: Lame, Shear, Young, Poisson, Bulk" << reset;
+	      exit(0);
+	    }
+	}
+    }
+}
+
+
 }
 
 
