@@ -3,7 +3,7 @@
  *         Class systems: declaration for slip sytems          *
  *                                    or martensitic variants  *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2008,2009,2011m2012 COLLARD Christophe
@@ -55,8 +55,8 @@
             copyright \htmlonly &#169; 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de MM&#233;canique des MatM&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
             copyright \htmlonly &#169; 2011, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2008-2012
+    \version 3.4.0
+    \date 2008-2019
     \bug none
     \warning none
 */
@@ -96,6 +96,10 @@
 #include <string.h>
 #endif
 
+#ifndef __tools_hpp
+#include "tools.hpp"
+#endif
+
 #ifndef __vectors_hpp
 #include "MOL++/vectors.hpp"
 #endif
@@ -131,9 +135,8 @@ template <class T> class systems
   public:
     //    systems () {nbsystems=0;}  // default constructor
     systems (const char* = "/data/systems.dat");
-    systems (const string = "/data/systems.dat");
     systems (ifstream&, int);
-    systems (const string&, T);
+    systems (const string& = "/data/systems.dat");
     systems (const systems<T>&);                 // copy constructor
     ~systems ();                                 // destructor
 
@@ -271,39 +274,6 @@ template <class T> systems<T>::systems (const char* path)
 }
 
 
-/*!
-  \brief Reads systems properties in a file and builds the associated Schmid tensors.
-
-  (default file is located in the current directory under 'data/systems.dat'). \n
-  This file contains the following informations : \n
-  the number of systems \n
-  the unit normal vector to the habit / slip plane and the unit vector in the displacement / slip direction for the first system.\n
-  \n
-  Then the constructor builds the Schmid tensor for each system.
-  \param filename filename
-*/
-
-//------------------------------------------------------------
-template <class T> systems<T>::systems (const string filename)
-//------------------------------------------------------------
-{
-  string text;
-
-  ifstream file(filename.c_str(), ios::in);
-  assert (!file.fail());
-
-  for (char ch=file.peek(); !isdigit(ch); ch=file.peek())
-    if (ch == ' ') file.get();
-    else getline (file, text);
-
-  file >> nbsystems;
-  Rij = new Schmid_tensor<T> [nbsystems];
-  for (int i=0; i<nbsystems; i++)
-    Rij[i] = Schmid_tensor<T>(file);  // construction of Schmid tensor for each martensitic variants
-  file.close();
-}
-
-
 /*!
   \brief Reads systems properties in a file and builds the associated Schmid tensors.
 
@@ -329,22 +299,19 @@ template <class T> systems<T>::systems (const string filename)
 /*!
   \brief Builds the Schmid tensor for each system of a given material.
 
-  \param material_type material type : values are "CuZnAl" and "CuAlBe"
-  \param nsystems number of systems
-  \param path filename
+  \param material_type material type : values are "CuZnAl" and "CuAlBe" and "FCC" or filename for material data
 */
 
-//------------------------------------------------------------------------------
-template <class T> systems<T>::systems (const string& material_type, T nsystems)
-//------------------------------------------------------------------------------
+//------------------------------------------------------------------
+template <class T> systems<T>::systems (const string& material_type)
+//------------------------------------------------------------------
 {
   string text;
 
-  nbsystems = nsystems;
-
   vector<T> n(3,false), m(3,false);
   if (material_type == "CuZnAl")
-    { n[1]=0.182; n[2]=0.669; n[3]=0.721;
+    { nbsystems = 24;
+      n[1]=0.182; n[2]=0.669; n[3]=0.721;
       m[1]=0.165; m[2]=0.655; m[3]=0.737;
       Rij = new Schmid_tensor<T> [nbsystems];
       matrix<T> N, M;
@@ -354,7 +321,8 @@ template <class T> systems<T>::systems (const string& material_type, T nsystems)
       Rij[i-1] = Schmid_tensor<T>(N[i],M[i]);  // construction of martensitic variants
     }
   else if (material_type == "CuAlBe")
-    { n[1]=0.168; n[2]=0.688; n[3]=0.705;
+    { nbsystems = 24;
+      n[1]=0.168; n[2]=0.688; n[3]=0.705;
       m[1]=0.121; m[2]=0.678; m[3]=0.725;
       Rij = new Schmid_tensor<T> [nbsystems];
       matrix<T> N, M;
@@ -364,7 +332,8 @@ template <class T> systems<T>::systems (const string& material_type, T nsystems)
       Rij[i-1] = Schmid_tensor<T>(N[i],M[i]);  // construction of martensitic variants
     }
   else if (material_type == "FCC")
-    { n[1]=1; n[2]=1; n[3]=1;
+    { nbsystems = 12;
+      n[1]=1; n[2]=1; n[3]=1;
       m[1]=1; m[2]=-1; m[3]=0;
       Rij = new Schmid_tensor<T> [nbsystems];
       matrix<T> N, M;
@@ -373,9 +342,15 @@ template <class T> systems<T>::systems (const string& material_type, T nsystems)
       for (int i=1; i<=nbsystems; i++)
 	Rij[i-1] = Schmid_tensor<T>(N[i],M[i]);  // construction of martensitic variants
     }
-  else
-    { cout << "No data for this material \n";
-      exit(0);
+  else // read from file
+    { ifstream file (material_type.c_str(), ios::in);
+      assert (!file.fail());
+
+      nbsystems = read_value<int> (file);
+      Rij = new Schmid_tensor<T> [nbsystems];
+      for (int i=0; i<nbsystems; i++)
+	Rij[i] = Schmid_tensor<T> (file);  // construction of Schmid tensor for each martensitic variants
+      file.close();
     }
 }
 
