@@ -1,13 +1,13 @@
 /***************************************************************
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2008,2012 COLLARD Christophe
- * copyright © 2008,2012 Centre National de la Recherche Scientifique
+ * copyright © 2008,2012,2014 COLLARD Christophe
+ * copyright © 2008,2012,2014 Centre National de la Recherche Scientifique
  * copyright © 2008 Arts et Métiers ParisTech
  * copyright © 2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
- * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2012,2014 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  *****************************************************************/
 
 /*
@@ -131,6 +131,9 @@ int test_Schmid_tensor (int detail)
   if (detail) affiche ("normal unit vector in the slip direction", vr.m()==m && vr1.m()==m1);
   else result *= (vr.m()==m && vr1.m()==m1);
 
+  if (detail) affiche ("Schmid tensor", vr.R() == (long double) 0.5 * ((n ^ m) + (m ^ n)));
+  else result *= (vr.R() == (long double) 0.5 * ((n ^ m) + (m ^ n)));
+
   cout << endl;
 
   cout << "============================================================== \n";
