@@ -1,15 +1,15 @@
 /***************************************************************
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.2.0                   *
+ *	             GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2006,2007,2008,2009,2012 COLLARD Christophe
- * copyright © 2006,2007,2008,2009,2012 Centre National de la Recherche Scientifique
+ * copyright © 2006,2007,2008,2009,2012,2018 COLLARD Christophe
+ * copyright © 2006,2007,2008,2009,2012,2018 Centre National de la Recherche Scientifique
  * copyright © 2006,2007,2008,2009 Arts et Métiers ParisTech
  * copyright © 2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2012,2018 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*
@@ -215,6 +215,16 @@ int test_cubic_elasticity_tensor (int detail)
   if (detail) affiche ("inv", strain==Tstrain2 && Czr.inv()==matrix2symtensor(gauss(symtensor2matrix(C4))));
   else result *= (strain==Tstrain2 && Czr.inv()==matrix2symtensor(gauss(symtensor2matrix(C4))));
 
+  cubic_elasticity_tensor<long double> Ccub;
+  Ccub.read ("data/cubic elasticity tensor.dat");
+  cubic_elasticity_tensor<long double> Ccub_test;
+  Ccub_test.Young (68000);
+  Ccub_test.Shear (33000);
+  Ccub_test.Poisson (0.34);
+  if (detail) affiche ("read", Ccub == Ccub_test);
+  else result *=  (Ccub == Ccub_test);
+
+
   cout << endl;
 
   cout << "============================================================== \n";
