@@ -1,15 +1,15 @@
 /***************************************************************
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.2.0                   *
+ *	             GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2003,2004,2005,2006,2007,2008,2009,2010,2012 COLLARD Christophe
- * copyright © 2003,2004,2005,2006,2007,2008,2009,2010,2012 Centre National de la Recherche Scientifique
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010,2012,2018 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010,2012,2018 Centre National de la Recherche Scientifique
  * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
  * copyright © 2003,2004,2005,2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2012,2018 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*
@@ -309,6 +309,14 @@ int test_isotropic_elasticity_tensor (int detail)
   if (detail) affiche ("cast conversion : isotropic_tensor -> isotropic_elasticity_tensor", Tie==C && Tie.Lame()==lambda && Tie.Shear()==mu);
   else result *=  (Tie==C && Tie.Lame()==lambda && Tie.Shear()==mu);
 
+  isotropic_elasticity_tensor<long double> Ciso;
+  Ciso.read ("data/isotropic elasticity tensor.dat");
+  isotropic_elasticity_tensor<long double> Ciso_test;
+  Ciso_test.Shear (30000);
+  Ciso_test.Poisson (0.3);
+  if (detail) affiche ("read", Ciso == Ciso_test);
+  else result *=  (Ciso == Ciso_test);
+
   cout << endl;
 
   epsilon = eps; // restore precision level for computations
