@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2008,2009,2012 COLLARD Christophe
@@ -85,11 +85,11 @@ bool test_systems (int detail)
     }
 
   string material_type = "CuZnAl";
-  systems<long double> CuZnAl("data/CuZnAl.dat"), CuZnAl2(material_type, 24);
+  systems<long double> CuZnAl("data/CuZnAl.dat"), CuZnAl2(material_type);
   material_type = "CuAlBe";
-  systems<long double> CuAlBe("data/CuAlBe.dat"), CuAlBe2(material_type, 24);
+  systems<long double> CuAlBe("data/CuAlBe.dat"), CuAlBe2(material_type);
   material_type = "FCC";
-  systems<long double> FCC("data/FCC.dat"), FCC2(material_type, 12);
+  systems<long double> FCC("data/FCC.dat"), FCC2(material_type);
 
   bool test = true;
   for (int i=1; i<=24; i++)
